import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-DxVRNMbC.js";import"./vendor-firebase-CdLSXhbt.js";import{pt as t}from"./vendor-vue-core-X6q-rGJs.js";import"./vendor-other-CyG3qq8S.js";import"./useFeatureFlags-JmUrt2h6.js";import"./api-Dal6nMaz.js";import"./vendor-markdown-Cola12Wc.js";import"./colorUtil-Cth7eqhK.js";import"./i18n-DjV_9lZM.js";import"./vendor-reka-ui-CHPbCe4i.js";import"./Button-C7dWyQyS.js";import{ln as n,qt as r,rr as i}from"./dialogService-rdPOt4rF.js";import"./systemStatsStore-BA-LdWdv.js";import"./useErrorHandling-Bf_c15cP.js";import"./dialogStore-CXD5Bcfy.js";import"./useCopyToClipboard-C74olorb.js";import"./vendor-tiptap-BXSIIPYY.js";import"./markdownRendererUtil-Bm7Umh6C.js";import"./useExternalLink-Cc30SNi3.js";r().registerExtension({name:`Comfy.Cloud.Subscription`,setup:async()=>{let{isLoggedIn:e}=i(),{requireActiveSubscription:r}=n(),checkSubscriptionStatus=()=>{e.value&&r()};t(()=>e.value,checkSubscriptionStatus,{immediate:!0})}});
//# sourceMappingURL=cloudSubscription-B7WdMMp7.js.map